diff mbox series

[v2,11/30] sections: Drop use of linux/types.h

Message ID 20230430013003.1047454-12-sjg@chromium.org
State Changes Requested
Delegated to: Tom Rini
Headers show
Series Allow building sandbox with MSYS2 | expand

Commit Message

Simon Glass April 30, 2023, 1:29 a.m. UTC
Use 'unsigned long' instead of 'ulong' so this file does not need to
include the linux/types.h header file. This allows it to be built with
MSYS2.

Signed-off-by: Simon Glass <sjg@chromium.org>
---

(no changes since v1)

 include/asm-generic/sections.h | 16 +++++++---------
 1 file changed, 7 insertions(+), 9 deletions(-)

Comments

Tom Rini April 30, 2023, 2:29 p.m. UTC | #1
On Sat, Apr 29, 2023 at 07:29:44PM -0600, Simon Glass wrote:

> Use 'unsigned long' instead of 'ulong' so this file does not need to
> include the linux/types.h header file. This allows it to be built with
> MSYS2.
> 
> Signed-off-by: Simon Glass <sjg@chromium.org>

Reviewed-by: Tom Rini <trini@konsulko.com>
Bin Meng May 1, 2023, 4:30 a.m. UTC | #2
On Sun, Apr 30, 2023 at 9:30 AM Simon Glass <sjg@chromium.org> wrote:
>
> Use 'unsigned long' instead of 'ulong' so this file does not need to
> include the linux/types.h header file. This allows it to be built with
> MSYS2.
>
> Signed-off-by: Simon Glass <sjg@chromium.org>
> ---
>
> (no changes since v1)
>
>  include/asm-generic/sections.h | 16 +++++++---------
>  1 file changed, 7 insertions(+), 9 deletions(-)
>

Reviewed-by: Bin Meng <bmeng@tinylab.org>
diff mbox series

Patch

diff --git a/include/asm-generic/sections.h b/include/asm-generic/sections.h
index 267f1db73f23..4ed9a8478cc5 100644
--- a/include/asm-generic/sections.h
+++ b/include/asm-generic/sections.h
@@ -8,8 +8,6 @@ 
 #ifndef _ASM_GENERIC_SECTIONS_H_
 #define _ASM_GENERIC_SECTIONS_H_
 
-#include <linux/types.h>
-
 /* References to section boundaries */
 
 extern char _text[], _stext[], _etext[];
@@ -71,7 +69,7 @@  extern char __image_copy_end[];
 extern void _start(void);
 
 /*
  * ARM defines its symbols as char[]. Other arches define them as ulongs.
  */
 #ifdef CONFIG_ARM
 
@@ -86,13 +84,13 @@  extern char __rel_dyn_end[];
 #else /* don't use offsets: */
 
 /* Exports from the Linker Script */
-extern ulong __data_end;
-extern ulong __rel_dyn_start;
-extern ulong __rel_dyn_end;
-extern ulong __bss_end;
-extern ulong _image_binary_end;
+extern unsigned long __data_end;
+extern unsigned long __rel_dyn_start;
+extern unsigned long __rel_dyn_end;
+extern unsigned long __bss_end;
+extern unsigned long _image_binary_end;
 
-extern ulong _TEXT_BASE;	/* code start */
+extern unsigned long _TEXT_BASE;	/* code start */
 
 #endif
@@ -71,7 +69,7 @@  extern char __image_copy_end[];
 
 /*
- * ARM defines its symbols as char[]. Other arches define them as ulongs.
+ * ARM defines its symbols as char[]. Other archs define them as unsigned long
  */
 #ifdef CONFIG_ARM